@@ -8,9 +8,9 @@ use Log::ger;
 use App::orgadb::Common;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-10-16'; # DATE
+our $DATE = '2022-10-17'; # DATE
 our $DIST = 'App-orgadb'; # DIST
-our $VERSION = '0.013'; # VERSION
+our $VERSION = '0.014'; # VERSION
 
 our %SPEC;
 
@@ -83,7 +83,7 @@ sub _select_single {
         my $expr = '';
 
         if (defined $args{category}) {
-            $expr .= 'Headline[level=1][title.text';
+            $expr .= 'Headline[level=1][title.as_string';
             if (ref $args{category} eq 'Regexp') {
                 $re_category = $args{category};
             } else {
@@ -95,7 +95,7 @@ sub _select_single {
 
         $expr .= (length $expr ? " " : "") . 'Headline[level=2]';
         if (defined $args{entry}) {
-            $expr .= '[title.text';
+            $expr .= '[title.as_string';
             if (ref $args{entry} eq 'Regexp') {
                 $re_entry = $args{entry};
             } else {
@@ -207,12 +207,12 @@ sub _select_single {
                     $res->[2] .= _highlight(
                         $clrtheme_obj,
                         $re_category,
-                        $entry->parent->title->text) . "/";
+                        $entry->parent->title->as_string) . "/";
                 }
                 $res->[2] .= _highlight(
                     $clrtheme_obj,
                     $re_entry,
-                    $entry->title->text,
+                    $entry->title->as_string,
                 );
                 $res->[2] .= "\n";
             }
@@ -478,7 +478,7 @@ App::orgadb - An opinionated Org addressbook toolset
 
 =head1 VERSION
 
-This document describes version 0.013 of App::orgadb (from Perl distribution App-orgadb), released on 2022-10-16.
+This document describes version 0.014 of App::orgadb (from Perl distribution App-orgadb), released on 2022-10-17.
 
 =head1 SYNOPSIS
 
@@ -523,6 +523,8 @@ matching field values to clipboard.
 If set to C<only>, then will not display matching fields to terminal and will
 only copy matching field values to clipboard.
 
+Mnemonic for short option C<-y> and C<-Y>: I<y>ank as in Emacs (C<C-y>).
+
 =item * B<color> => I<str> (default: "auto")
 
 Whether to use color.
@@ -537,7 +539,10 @@ Return just the number of matching entries instead of showing them.
 
 =item * B<detail> => I<bool>
 
-(No description)
+Instead of showing matching field values, display the whole entry.
+
+Mnemonic for shortcut option C<-l>: the option C<-l> is usually used for the short
+version of C<--detail>, as in I<ls> Unix command.
 
 =item * B<entry> => I<str_or_re>
 
@@ -559,19 +564,22 @@ The rules are best specified in the configuration as opposed to on the
 command-line option. An example (the lines below are writen in configuration
 file in IOD syntax, as rows of JSON hashes):
 
- ; by default remove all comments in field values when 'hide_field_name'
- ; option is set (which usually means we want to copy paste things)
+ ; remove all comments in field values when 'hide_field_name' option is set
+ ; (which usually means we want to copy paste things)
+ 
  field_value_formatter_rules={"hide_field_name":true, "formatters":[ ["Str::remove_comment"] ]}
  
- ; by default normalize phone numbers using Phone::format_phone_idn_nospace
- ; when 'hide_field_name' option is set (which usually means we want to copy
- ; paste things). e.g. '0812-1234-5678' becomes '+6281212345678'.
- field_value_formatter_rules={"field_name_matches":"/phone|wa|whatsapp/i", "hide_field_name":true, "formatters":[ ["Phone::format_phone_idn_nospace"] ]}
+ ; normalize phone numbers using Phone::format + Str::remove_whitespace when
+ ; 'hide_field_name' option is set (which usually means we want to copy paste
+ ; things). e.g. '0812-1234-5678' becomes '+6281212345678'.
+ 
+ field_value_formatter_rules={"field_name_matches":"/phone|wa|whatsapp/i", "hide_field_name":true, "formatters":[ ["Phone::format", "Str::remove_whitespace"] ]}
  
  ; but if 'hide_field_name' field is not set, normalize phone numbers using
- ; Phone::format_phone_idn which is more easier to see (e.g. '+62 812 1234
- ; 5678').
- field_value_formatter_rules={"field_name_matches":"/phone|wa|whatsapp/i", "hide_field_name":false, "formatters":[ ["Phone::format_phone_idn"] ]}
+ ; Phone::format without removing whitespaces, which is easier to see (e.g.
+ ; '+62 812 1234 5678').
+ 
+ field_value_formatter_rules={"field_name_matches":"/phone|wa|whatsapp/i", "hide_field_name":false, "formatters":[ ["Phone::format"] ]}
 
 Condition keys:
 
@@ -654,6 +662,9 @@ Do not show entry headline.
 
 Do not show field names, just show field values.
 
+Mnemonic for short option C<-N>: field I<N>ame (uppercase letter usually means
+/no/).
+
 =item * B<no_field_value_formatters> => I<true>
 
 Do not apply formatters for field value (overrides --field-value-formatter option).
