@@ -6,9 +6,9 @@ use warnings;
 use Log::ger;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-10-16'; # DATE
+our $DATE = '2022-10-17'; # DATE
 our $DIST = 'App-orgadb'; # DIST
-our $VERSION = '0.013'; # VERSION
+our $VERSION = '0.014'; # VERSION
 
 sub _heading_from_line {
     my $heading = shift;
@@ -309,11 +309,25 @@ our %argspecs_select = (
         schema => 'true*',
         cmdline_aliases => {N=>{}},
         tags => ['category:output'],
+        description => <<'_',
+
+Mnemonic for short option `-N`: field *N*ame (uppercase letter usually means
+/no/).
+
+_
     },
     detail => {
         schema => 'bool*',
         cmdline_aliases => {l=>{}},
         tags => ['category:output'],
+        description => <<'_',
+
+Instead of showing matching field values, display the whole entry.
+
+Mnemonic for shortcut option `-l`: the option `-l` is usually used for the short
+version of `--detail`, as in *ls* Unix command.
+
+_
     },
     count => {
         summary => 'Return just the number of matching entries instead of showing them',
@@ -352,19 +366,22 @@ The rules are best specified in the configuration as opposed to on the
 command-line option. An example (the lines below are writen in configuration
 file in IOD syntax, as rows of JSON hashes):
 
-    ; by default remove all comments in field values when 'hide_field_name'
-    ; option is set (which usually means we want to copy paste things)
+    ; remove all comments in field values when 'hide_field_name' option is set
+    ; (which usually means we want to copy paste things)
+
     field_value_formatter_rules={"hide_field_name":true, "formatters":[ ["Str::remove_comment"] ]}
 
-    ; by default normalize phone numbers using Phone::format_phone_idn_nospace
-    ; when 'hide_field_name' option is set (which usually means we want to copy
-    ; paste things). e.g. '0812-1234-5678' becomes '+6281212345678'.
-    field_value_formatter_rules={"field_name_matches":"/phone|wa|whatsapp/i", "hide_field_name":true, "formatters":[ ["Phone::format_phone_idn_nospace"] ]}
+    ; normalize phone numbers using Phone::format + Str::remove_whitespace when
+    ; 'hide_field_name' option is set (which usually means we want to copy paste
+    ; things). e.g. '0812-1234-5678' becomes '+6281212345678'.
+
+    field_value_formatter_rules={"field_name_matches":"/phone|wa|whatsapp/i", "hide_field_name":true, "formatters":[ ["Phone::format", "Str::remove_whitespace"] ]}
 
     ; but if 'hide_field_name' field is not set, normalize phone numbers using
-    ; Phone::format_phone_idn which is more easier to see (e.g. '+62 812 1234
-    ; 5678').
-    field_value_formatter_rules={"field_name_matches":"/phone|wa|whatsapp/i", "hide_field_name":false, "formatters":[ ["Phone::format_phone_idn"] ]}
+    ; Phone::format without removing whitespaces, which is easier to see (e.g.
+    ; '+62 812 1234 5678').
+
+    field_value_formatter_rules={"field_name_matches":"/phone|wa|whatsapp/i", "hide_field_name":false, "formatters":[ ["Phone::format"] ]}
 
 Condition keys:
 
@@ -397,7 +414,14 @@ _
                 ns_prefix => 'Data::Sah::Filter::perl',
             );
         },
-        cmdline_aliases => {fvfmt=>{}, f=>{}},
+        cmdline_aliases => {
+            fvfmt=>{},
+            f=>{},
+            remove_nondigits   => {is_flag=>1, summary=>'Shortcut for --field-value-formatter Str::remove_nondigit'   , code=>sub { $_[0]{field_value_formatters} //= []; push @{ $_[0]{field_value_formatters} }, 'Str::remove_nondigit'   } },
+            remove_comments    => {is_flag=>1, summary=>'Shortcut for --field-value-formatter Str::remove_comment'    , code=>sub { $_[0]{field_value_formatters} //= []; push @{ $_[0]{field_value_formatters} }, 'Str::remove_comment'    } },
+            remove_whitespaces => {is_flag=>1, summary=>'Shortcut for --field-value-formatter Str::remove_whitespaces', code=>sub { $_[0]{field_value_formatters} //= []; push @{ $_[0]{field_value_formatters} }, 'Str::remove_whitespace' } },
+            format_phone       => {is_flag=>1, summary=>'Shortcut for --field-value-formatter Phone::format'          , code=>sub { $_[0]{field_value_formatters} //= []; push @{ $_[0]{field_value_formatters} }, 'Phone::format'          } },
+        },
         tags => ['category:output'],
         description => <<'_',
 
@@ -444,9 +468,13 @@ matching field values to clipboard.
 If set to `only`, then will not display matching fields to terminal and will
 only copy matching field values to clipboard.
 
+Mnemonic for short option `-y` and `-Y`: *y*ank as in Emacs (`C-y`).
+
 _
         cmdline_aliases => {
-            clipboard_only => {is_flag=>1, summary=>'Alias for --clipboard=only', code=>sub { $_[0]{clipboard} = 'only' }},
+            clipboard_only => {is_flag=>1, summary=>'Shortcut for --clipboard=only', code=>sub { $_[0]{clipboard} = 'only' }},
+            y => {is_flag=>1, summary=>'Shortcut for --clipboard=tee', code=>sub { $_[0]{clipboard} = 'tee' }},
+            Y => {is_flag=>1, summary=>'Shortcut for --clipboard=only', code=>sub { $_[0]{clipboard} = 'only' }},
         },
         tags => ['category:output'],
     },
@@ -467,7 +495,7 @@ App::orgadb::Common
 
 =head1 VERSION
 
-This document describes version 0.013 of App::orgadb::Common (from Perl distribution App-orgadb), released on 2022-10-16.
+This document describes version 0.014 of App::orgadb::Common (from Perl distribution App-orgadb), released on 2022-10-17.
 
 =head1 HOMEPAGE
 
